import java.util.HashMap;

/**
 * Ett program som demonstrerar anvndandet av en HashMap
 * @author fki
 *
 */
public class HashDemo {

	private HashMap<String, Person> directory = new HashMap<String, Person>();
	
	/**
	 * Person r en s k intern klass, och den r inte annorlunda mot en vanlig
	 * klass frutom att den r deklarerad inuti klassen HashDemo.
	 * Interna klasser ska ses som hjlpobjekt till sin omgivande klass.
	 * Instanser av interna klasser har ocks en osynlig referens till den
	 * omgivande instans som skapat dem, och kan drmed komma t metoder och
	 * variabler i den omgivande instansen.
	 * 
	 * @author fki@kth.se
	 *
	 */
	protected class Person {
		private String name;
		private String building;
		private String floor;
		private String room;
		private String tele;
		
		public Person (String name, String building, String floor, String room, String tele) {
			this.name = name;
			this.building = building;
			this.floor = floor;
			this.room = room;
			this.tele = tele;
		}
				
		public String toString () {
			return 
					String.format("%s : is in %s, on floor %s, room %s, tel: %s",
							name, building, floor, room, tele);
		}
	}
	
	private void loadPersons (HashMap<String, Person> dir) {
		Person p = new Person("Fredrik", "Electrum", "4", "4321", "4098");
		dir.put("Fredrik", p);
		dir.put("4098", p);
		
		p = new Person("Karina", "Forum", "7", "7654", "1234");
		dir.put("Karina", p);
		dir.put("1234", p);
		
		p = new Person("Olle", "Kista C", "4", "B12-5", "654523");
		dir.put("Olle", p);
		dir.put("654523",  p);
	}
	
	private void lookupAndPrintByKey(String key) {
		Person p = directory.get(key);
		if (p != null) {
			System.out.println(p);
		}
		else {
			System.out.println("Ingen person funnen");
		}
	}
	
	private void lookupAndPrintByName(String name) {
		System.out.println("Sker person med namn " + name);
		lookupAndPrintByKey(name);
	}
	
	private void lookupAndPrintByTele(String tele) {
		System.out.println("Sker person med tele " + tele);
		lookupAndPrintByKey(tele);
	}
	
	private void performLookups() {
		lookupAndPrintByName("Fredrik");
		lookupAndPrintByTele("4098");
		// However, this also works because the keys are just strings
		lookupAndPrintByTele("Karina");
	}
	
	public void runHashDemo() {
		loadPersons(directory); // Ladda katalogen med personer
		performLookups(); // Gr ngra slagningar
	}
	/**
	 * @param args
	 */
	public static void main(String[] args) {
		new HashDemo().runHashDemo();
	}

}
